==> 0.1.64.tar.gz: lib/network_resources/model/product.dart <==
class ProductModel {
  int? id;
  String? label;
  String? description;
  String? productSerial;
  int? purchasedAt;
  int? warrantyUntil;
  String? productCat;
  String? categoryColor;
  String? productRef;
  String? codeReference;
  String? pictureUrl;
  int? statusId;
  String? statusLabel;
  String? statusColor;
  int? statusDisplay;
  int? lat;
  int? lng;
  int? placeId;
  String? placeCity;
  String? placeLabel;
  double? placeLng;
  double? placeLat;
  String? placeCountry;
  String? placeZip;
  String? placeStreet1;
  String? placeStreet2;
  String? utcModifier;
  String? macAddress;
  String? moreInfos;
  int? hasOwner;

  ProductModel(
      {this.id,
      this.label,
      this.description,
      this.productSerial,
      this.purchasedAt,
      this.warrantyUntil,
      this.productCat,
      this.categoryColor,
      this.productRef,
      this.codeReference,
      this.pictureUrl,
      this.statusId,
      this.statusLabel,
      this.statusColor,
      this.statusDisplay,
      this.lat,
      this.lng,
      this.placeId,
      this.placeCity,
      this.placeLabel,
      this.placeLng,
      this.placeLat,
      this.placeCountry,
      this.placeZip,
      this.placeStreet1,
      this.placeStreet2,
      this.utcModifier,
      this.macAddress,
      this.moreInfos,
      this.hasOwner});

  ProductModel.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) this.id = json["id"];
    if (json["label"] is String) this.label = json["label"];
    if (json["description"] is String) this.description = json["description"];
    if (json["productSerial"] is String)
      this.productSerial = json["productSerial"];
    if (json["purchasedAt"] is int) this.purchasedAt = json["purchasedAt"];
    if (json["warrantyUntil"] is int)
      this.warrantyUntil = json["warrantyUntil"];
    if (json["productCat"] is String) this.productCat = json["productCat"];
    if (json["categoryColor"] is String)
      this.categoryColor = json["categoryColor"];
    if (json["productRef"] is String) this.productRef = json["productRef"];
    if (json["codeReference"] is String)
      this.codeReference = json["codeReference"];
    if (json["pictureUrl"] is String) this.pictureUrl = json["pictureUrl"];
    if (json["statusId"] is int) this.statusId = json["statusId"];
    if (json["statusLabel"] is String) this.statusLabel = json["statusLabel"];
    if (json["statusColor"] is String) this.statusColor = json["statusColor"];
    if (json["statusDisplay"] is int)
      this.statusDisplay = json["statusDisplay"];
    if (json["lat"] is int) this.lat = json["lat"];
    if (json["lng"] is int) this.lng = json["lng"];
    if (json["placeId"] is int) this.placeId = json["placeId"];
    if (json["placeCity"] is String) this.placeCity = json["placeCity"];
    if (json["placeLabel"] is String) this.placeLabel = json["placeLabel"];
    if (json["placeLng"] is double) this.placeLng = json["placeLng"];
    if (json["placeLat"] is double) this.placeLat = json["placeLat"];
    if (json["placeCountry"] is String)
      this.placeCountry = json["placeCountry"];
    if (json["placeZip"] is String) this.placeZip = json["placeZip"];
    if (json["placeStreet1"] is String)
      this.placeStreet1 = json["placeStreet1"];
    if (json["placeStreet2"] is String)
      this.placeStreet2 = json["placeStreet2"];
    if (json["utcModifier"] is String) this.utcModifier = json["utcModifier"];
    if (json["macAddress"] is String) this.macAddress = json["macAddress"];
    if (json["moreInfos"] is String) this.moreInfos = json["moreInfos"];
    if (json["hasOwner"] is int) this.hasOwner = json["hasOwner"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["label"] = this.label;
    data["description"] = this.description;
    data["productSerial"] = this.productSerial;
    data["purchasedAt"] = this.purchasedAt;
    data["warrantyUntil"] = this.warrantyUntil;
    data["productCat"] = this.productCat;
    data["categoryColor"] = this.categoryColor;
    data["productRef"] = this.productRef;
    data["codeReference"] = this.codeReference;
    data["pictureUrl"] = this.pictureUrl;
    data["statusId"] = this.statusId;
    data["statusLabel"] = this.statusLabel;
    data["statusColor"] = this.statusColor;
    data["statusDisplay"] = this.statusDisplay;
    data["lat"] = this.lat;
    data["lng"] = this.lng;
    data["placeId"] = this.placeId;
    data["placeCity"] = this.placeCity;
    data["placeLabel"] = this.placeLabel;
    data["placeLng"] = this.placeLng;
    data["placeLat"] = this.placeLat;
    data["placeCountry"] = this.placeCountry;
    data["placeZip"] = this.placeZip;
    data["placeStreet1"] = this.placeStreet1;
    data["placeStreet2"] = this.placeStreet2;
    data["utcModifier"] = this.utcModifier;
    data["macAddress"] = this.macAddress;
    data["moreInfos"] = this.moreInfos;
    data["hasOwner"] = this.hasOwner;
    return data;
  }
}

==> 0.1.86.tar.gz: lib/network_resources/model/product.dart <==
class ProductModel {
  int? terminalId;

  int? id;
  String? label;
  String? description;
  String? productSerial;
  int? purchasedAt;
  int? warrantyUntil;
  String? productCat;
  String? categoryColor;
  String? productRef;
  String? codeReference;
  String? pictureUrl;
  int? statusId;
  String? statusLabel;
  String? statusColor;
  int? statusDisplay;
  double? lat;
  double? lng;
  int? placeId;
  String? placeCity;
  String? placeLabel;
  double? placeLng;
  double? placeLat;
  String? placeCountry;
  String? placeZip;
  String? placeStreet1;
  String? placeStreet2;
  String? utcModifier;
  String? macAddress;
  String? moreInfos;
  int? hasOwner;

  ProductModel(
      {this.terminalId,
      this.id,
      this.label,
      this.description,
      this.productSerial,
      this.purchasedAt,
      this.warrantyUntil,
      this.productCat,
      this.categoryColor,
      this.productRef,
      this.codeReference,
      this.pictureUrl,
      this.statusId,
      this.statusLabel,
      this.statusColor,
      this.statusDisplay,
      this.lat,
      this.lng,
      this.placeId,
      this.placeCity,
      this.placeLabel,
      this.placeLng,
      this.placeLat,
      this.placeCountry,
      this.placeZip,
      this.placeStreet1,
      this.placeStreet2,
      this.utcModifier,
      this.macAddress,
      this.moreInfos,
      this.hasOwner});

  ProductModel.fromJson(Map<String, dynamic> json) {
    if (json["terminalId"] is int) this.terminalId = json["terminalId"];
    if (json["id"] is int) this.id = json["id"];
    if (json["label"] is String) this.label = json["label"];
    if (json["description"] is String) this.description = json["description"];
    if (json["productSerial"] is String)
      this.productSerial = json["productSerial"];
    if (json["purchasedAt"] is int) this.purchasedAt = json["purchasedAt"];
    if (json["warrantyUntil"] is int)
      this.warrantyUntil = json["warrantyUntil"];
    if (json["productCat"] is String) this.productCat = json["productCat"];
    if (json["categoryColor"] is String)
      this.categoryColor = json["categoryColor"];
    if (json["productRef"] is String) this.productRef = json["productRef"];
    if (json["codeReference"] is String)
      this.codeReference = json["codeReference"];
    if (json["pictureUrl"] is String) this.pictureUrl = json["pictureUrl"];
    if (json["statusId"] is int) this.statusId = json["statusId"];
    if (json["statusLabel"] is String) this.statusLabel = json["statusLabel"];
    if (json["statusColor"] is String) this.statusColor = json["statusColor"];
    if (json["statusDisplay"] is int)
      this.statusDisplay = json["statusDisplay"];
    if (json["lat"] is double) this.lat = json["lat"];
    if (json["lng"] is double) this.lng = json["lng"];
    if (json["placeId"] is int) this.placeId = json["placeId"];
    if (json["placeCity"] is String) this.placeCity = json["placeCity"];
    if (json["placeLabel"] is String) this.placeLabel = json["placeLabel"];
    if (json["placeLng"] is double) this.placeLng = json["placeLng"];
    if (json["placeLat"] is double) this.placeLat = json["placeLat"];
    if (json["placeCountry"] is String)
      this.placeCountry = json["placeCountry"];
    if (json["placeZip"] is String) this.placeZip = json["placeZip"];
    if (json["placeStreet1"] is String)
      this.placeStreet1 = json["placeStreet1"];
    if (json["placeStreet2"] is String)
      this.placeStreet2 = json["placeStreet2"];
    if (json["utcModifier"] is String) this.utcModifier = json["utcModifier"];
    if (json["macAddress"] is String) this.macAddress = json["macAddress"];
    if (json["moreInfos"] is String) this.moreInfos = json["moreInfos"];
    if (json["hasOwner"] is int) this.hasOwner = json["hasOwner"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["terminalId"] = this.terminalId;
    data["id"] = this.id;
    data["label"] = this.label;
    data["description"] = this.description;
    data["productSerial"] = this.productSerial;
    data["purchasedAt"] = this.purchasedAt;
    data["warrantyUntil"] = this.warrantyUntil;
    data["productCat"] = this.productCat;
    data["categoryColor"] = this.categoryColor;
    data["productRef"] = this.productRef;
    data["codeReference"] = this.codeReference;
    data["pictureUrl"] = this.pictureUrl;
    data["statusId"] = this.statusId;
    data["statusLabel"] = this.statusLabel;
    data["statusColor"] = this.statusColor;
    data["statusDisplay"] = this.statusDisplay;
    data["lat"] = this.lat;
    data["lng"] = this.lng;
    data["placeId"] = this.placeId;
    data["placeCity"] = this.placeCity;
    data["placeLabel"] = this.placeLabel;
    data["placeLng"] = this.placeLng;
    data["placeLat"] = this.placeLat;
    data["placeCountry"] = this.placeCountry;
    data["placeZip"] = this.placeZip;
    data["placeStreet1"] = this.placeStreet1;
    data["placeStreet2"] = this.placeStreet2;
    data["utcModifier"] = this.utcModifier;
    data["macAddress"] = this.macAddress;
    data["moreInfos"] = this.moreInfos;
    data["hasOwner"] = this.hasOwner;
    return data;
  }
}
